@@ -1,6 +1,28 @@
 # variable treatments type def: list { origvar, newvars, f(col,args), args, treatmentName, scales } can share orig var
 
 
+
+#' vtreat: A Statistically Sound 'data.frame' Processor/Conditioner
+#'
+#' A 'data.frame' processor/conditioner that prepares real-world data for predictive modeling in a statistically sound manner.
+#' 'vtreat' prepares variables so that data has fewer exceptional cases, making
+#' it easier to safely use models in production. Common problems 'vtreat' defends
+#' against: 'Inf', 'NA', too many categorical levels, rare categorical levels, and new
+#' categorical levels (levels seen during application, but not during training).
+#' 'vtreat::prepare' should be used as you would use 'model.matrix'.
+#'
+#'
+#'For more information:
+#' \itemize{
+#'   \item \code{vignette('vtreat', package='vtreat')}
+#'   \item \code{vignette(package='vtreat')}
+#'   \item Website: \url{https://github.com/WinVector/vtreat} }
+#'
+#' @docType package
+#' @name vtreat
+NULL
+
+
 #' @importFrom stats aggregate anova as.formula binomial chisq.test fisher.test glm lm lm.wfit pchisq pf quantile
 #' @importFrom utils packageVersion
 NULL
@@ -290,8 +312,8 @@ designTreatmentsZ <- function(dframe,varlist,
 #' 
 #' @param treatmentplan Plan built by designTreantmentsC() or designTreatmentsN()
 #' @param dframe Data frame to be treated
-#' @param pruneSig suppress variables with significance above this level
 #' @param ... no additional arguments, declared to forced named binding of later arguments
+#' @param pruneSig suppress variables with significance above this level
 #' @param scale optional if TRUE replace numeric variables with single variable model regressions ("move to outcome-scale").  These have mean zero and (for varaibles with signficant less than 1) slope 1 when regressed  (lm for regression problems/glm for classificaiton problems) against outcome.
 #' @param doCollar optional if TRUE collar numeric variables by cutting off after a tail-probability specified by collarProb during treatment design.
 #' @param varRestriction optional list of treated variable names to restrict to
@@ -304,21 +326,23 @@ designTreatmentsZ <- function(dframe,varlist,
 #'     z=c(1,2,3,4,5,6,7),y=c(0,0,0,1,0,1,1))
 #' dTestN <- data.frame(x=c('a','b','c',NA),z=c(10,20,30,NA))
 #' treatmentsN = designTreatmentsN(dTrainN,colnames(dTrainN),'y')
-#' dTrainNTreated <- prepare(treatmentsN,dTrainN,1.0)
-#' dTestNTreated <- prepare(treatmentsN,dTestN,1.0)
+#' dTrainNTreated <- prepare(treatmentsN,dTrainN, pruneSig=1.0)
+#' dTestNTreated <- prepare(treatmentsN,dTestN, pruneSig=1.0)
 #' 
 #' dTrainC <- data.frame(x=c('a','a','a','b','b','b'),
 #'     z=c(1,2,3,4,5,6),y=c(FALSE,FALSE,TRUE,FALSE,TRUE,TRUE))
 #' dTestC <- data.frame(x=c('a','b','c',NA),z=c(10,20,30,NA))
 #' treatmentsC <- designTreatmentsC(dTrainC,colnames(dTrainC),'y',TRUE)
-#' dTrainCTreated <- prepare(treatmentsC,dTrainC,1.0)
-#' dTestCTreated <- prepare(treatmentsC,dTestC,1.0)
+#' dTrainCTreated <- prepare(treatmentsC,dTrainC, pruneSig=1.0)
+#' dTestCTreated <- prepare(treatmentsC,dTestC, pruneSig=1.0)
 #' 
 #' 
 #' @export
-prepare <- function(treatmentplan,dframe,pruneSig,
+prepare <- function(treatmentplan,dframe,
                     ...,
-                    scale=FALSE,doCollar=FALSE,
+                    pruneSig= NULL,
+                    scale=FALSE,
+                    doCollar=FALSE,
                     varRestriction=c(),
                     parallelCluster=NULL) {
   .checkArgs1(dframe=dframe,...)
